@@ -85,6 +85,16 @@ class ActiveResource(object):
         return cls._parse_xml(xml)
     find = classmethod(find)
     
+    def perform_action(self, action, method='GET', **params):
+        status, xml = self.__class__._make_request(self, method, params, action=action)
+        if not str(status[0]).startswith('2'):
+            raise ActiveResourceException('%s: %s' % (status, xml))
+            
+        if '<' in xml:
+            return self.__class__._parse_xml(xml)
+        else:
+            return True
+    
     def save(self):
         if getattr(self, 'id', None):
             method = 'PUT'
@@ -107,9 +117,12 @@ class ActiveResource(object):
         
         return True
         
-    def _get_path(self):
+    def _get_path(self, action=None):
         if getattr(self, 'id', None):
-            return '%s/%s.xml' % (self.Meta.path_root, self.id)
+            obj_path = '%s/%s' % (self.Meta.path_root, self.id)
+            if action:
+                obj_path = '%s/%s' % (obj_path, action)
+            return '%s.xml' % (obj_path)
         else:
             return self.Meta.base_path
                 
@@ -151,7 +164,7 @@ class ActiveResource(object):
         return obj
     _parse_xml = classmethod(_parse_xml)
     
-    def _make_request(cls, obj=None, method='GET', params={}, headers={}):        
+    def _make_request(cls, obj=None, method='GET', params={}, headers={}, action=None):        
         if cls.Meta.auth and not headers.has_key('Authorization'):
             headers['Authorization'] = cls.Meta.auth
             
@@ -166,7 +179,7 @@ class ActiveResource(object):
         params = urllib.urlencode(params)
         
         if obj:
-            path = obj._get_path()
+            path = obj._get_path(action)
         else:
             path = cls.Meta.base_path
             
